# kenghwee
A package where a meme becomes a reality.

## Description

As of now, the `kenghwee` package supports four things:

- `solution`: Living up the meme `from kenghwee import solution`
- `mission04`: You must be truly desperate to come to this for help...
- `rmrf`: `sudo rm -rf ~/`, goodbye!
- `cs1010s`: Very random, trust me

## Installation

### Normal installation

```bash
pip install kenghwee
```

### Development installation

```bash
git clone https://github.com/RussellDash332/kenghwee.git
cd kenghwee
pip install --editable .
```

## Usage
```python
>>> import kenghwee
>>> help(kenghwee) # help, Keng Hwee!
>>> from kenghwee import solution
```

## Contributing
Make a pull request, that's it :)